==> datapark-facade-1.2.22-sources.jar: com/bxm/datapark/facade/adpopup/model/vo/PopupPositionVo.java <==
package com.bxm.datapark.facade.adpopup.model.vo;


import java.io.Serializable;

/**
 * 出券弹窗-广告位
 *
 * @author zhounan
 * created on 2018/8/2
 */
public class PopupPositionVo implements Serializable,CommonPopupAnalysisVo {

    private String appKey;

    private Integer scene;
    /**
     * 弹窗名称
     */
    private String popupName;

    /**
     * 弹窗id
     */
    private String popupid;

    /**
     * 弹窗uv
     */
    private Integer popupUv;

    /**
     * 弹窗uv
     */
    private Integer sendUv;

    /**
     * 发券量
     */
    private Integer openPv;

    /**
     * 点击量
     */
    private Integer clickPv;

    /**
     * 点击率
     */
    private double clickRate;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * business
     */
    private String business;

    /**
     * 广告位名称
     */
    private String positionName;

    /**
     * 广告位id
     */
    private String positionId;

    /**
     * 编号
     */
    private String no;

    @Override
    public String getPopupName() {
        return popupName;
    }

    @Override
    public void setPopupName(String popupName) {
        this.popupName = popupName;
    }

    @Override
    public String getPopupid() {
        return popupid;
    }

    @Override
    public void setPopupid(String popupid) {
        this.popupid = popupid;
    }

    @Override
    public Integer getPopupUv() {
        return popupUv;
    }

    @Override
    public void setPopupUv(Integer popupUv) {
        this.popupUv = popupUv;
    }

    @Override
    public Integer getOpenPv() {
        return openPv;
    }

    @Override
    public void setOpenPv(Integer openPv) {
        this.openPv = openPv;
    }

    @Override
    public Integer getClickPv() {
        return clickPv;
    }

    @Override
    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    @Override
    public double getClickRate() {
        return clickRate;
    }

    @Override
    public void setClickRate(double clickRate) {
        this.clickRate = clickRate;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    @Override
    public String getPositionId() {
        return positionId;
    }

    @Override
    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public Integer getScene() {
        return scene;
    }

    public void setScene(Integer scene) {
        this.scene = scene;
    }

    public Integer getSendUv() {
        return sendUv;
    }

    public void setSendUv(Integer sendUv) {
        this.sendUv = sendUv;
    }

    @Override
    public String getMediaName() {
        return mediaName;
    }

    @Override
    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }
}

==> datapark-facade-2.0.3-sources.jar: com/bxm/datapark/facade/adpopup/model/vo/PopupPositionVo.java <==
package com.bxm.datapark.facade.adpopup.model.vo;


import java.io.Serializable;

/**
 * 出券弹窗-广告位
 *
 * @author zhounan
 * created on 2018/8/2
 */
public class PopupPositionVo implements Serializable,CommonPopupAnalysisVo {

    private static final long serialVersionUID = -6819848620396361557L;

    private String appKey;

    private Integer scene;
    /**
     * 弹窗名称
     */
    private String popupName;

    /**
     * 弹窗id
     */
    private String popupid;

    /**
     * 弹窗uv
     */
    private Integer popupUv;

    /**
     * 弹窗uv
     */
    private Integer sendUv;

    /**
     * 发券量
     */
    private Integer openPv;

    /**
     * 点击量
     */
    private Integer clickPv;

    /**
     * 点击率
     */
    private double clickRate;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * business
     */
    private String business;

    /**
     * 广告位名称
     */
    private String positionName;

    /**
     * 广告位id
     */
    private String positionId;

    /**
     * 编号
     */
    private String no;
    
    /**
     * 媒体类型名称
     */
    private String mediaTypeName;

    /**
     * 媒体分类名称
     */
    private String mediaClass;


    /**
     * 媒体子分类名称
     */
    private String mediaChildClass;


    @Override
    public String getPopupName() {
        return popupName;
    }

    @Override
    public void setPopupName(String popupName) {
        this.popupName = popupName;
    }

    @Override
    public String getPopupid() {
        return popupid;
    }

    @Override
    public void setPopupid(String popupid) {
        this.popupid = popupid;
    }

    @Override
    public Integer getPopupUv() {
        return popupUv;
    }

    @Override
    public void setPopupUv(Integer popupUv) {
        this.popupUv = popupUv;
    }

    @Override
    public Integer getOpenPv() {
        return openPv;
    }

    @Override
    public void setOpenPv(Integer openPv) {
        this.openPv = openPv;
    }

    @Override
    public Integer getClickPv() {
        return clickPv;
    }

    @Override
    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    @Override
    public double getClickRate() {
        return clickRate;
    }

    @Override
    public void setClickRate(double clickRate) {
        this.clickRate = clickRate;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    @Override
    public String getPositionId() {
        return positionId;
    }

    @Override
    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public Integer getScene() {
        return scene;
    }

    public void setScene(Integer scene) {
        this.scene = scene;
    }

    public Integer getSendUv() {
        return sendUv;
    }

    public void setSendUv(Integer sendUv) {
        this.sendUv = sendUv;
    }

    @Override
    public String getMediaName() {
        return mediaName;
    }

    @Override
    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    public String getMediaTypeName() {
        return mediaTypeName;
    }

    public void setMediaTypeName(String mediaTypeName) {
        this.mediaTypeName = mediaTypeName;
    }

    public String getMediaClass() {
        return mediaClass;
    }

    public void setMediaClass(String mediaClass) {
        this.mediaClass = mediaClass;
    }

    public String getMediaChildClass() {
        return mediaChildClass;
    }

    public void setMediaChildClass(String mediaChildClass) {
        this.mediaChildClass = mediaChildClass;
    }

}
